topics.InterestsByController (Interests) — amici1

# `topics.InterestsByController` (Interests)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: owner_type>`

- `<lino.modlib.gfks.fields.GenericForeignKeyIdField: owner_id>`

- `<django.db.models.fields.related.ForeignKey: topic>`

- `<lino.core.fields.RichTextField: remark>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.modlib.gfks.fields.GenericForeignKey object at 0x7fc81dc53240>`

Detail fields

- Partner (partner) : See `<django.db.models.fields.related.ForeignKey: partner>`.

- `<Panel main_2 in lino.core.layouts.DetailLayout on lino_xl.lib.topics.models.Interests>`

- Remark (remark) : See `<lino.core.fields.RichTextField: remark>`.

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Interest.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

## Filter parameters